@@ -161,18 +161,20 @@ class WorkspaceBuilder(object):
             else:
                 window_name = wconf['window_name']
 
+            w1 = None
             if i == int(1):  # if first window, use window 1
-                # w = s.select_window(1)
-                w = s.attached_window()
-                w = w.rename_window(window_name)
-            else:
-                w = s.new_window(
-                    window_name=window_name,
-                    attach=False  # do not move to the new window
-                )
+                w1 = s.attached_window()
+                w1.attached_pane().send_keys('la')
+            w = s.new_window(
+                window_name=window_name,
+                start_directory=wconf['start_directory'] if 'start_directory' in wconf else None,
+                attach=False  # do not move to the new window
+            )
 
+            if i == int(1) and w1:  # if first window, use window 1
+                w1.kill_window()
             assert(isinstance(w, Window))
-
+            s.server._update_windows()
             if 'options' in wconf and isinstance(wconf['options'], dict):
                 for key, val in wconf['options'].items():
                     w.set_window_option(key, val)
@@ -240,8 +242,8 @@ def freeze(session):
             pconf = {}
             pconf['shell_command'] = []
             if 'shell_command_before' not in wconf:
-                pconf['shell_command'].append(
-                    'cd ' + p.get('pane_current_path'))
+               pconf['shell_command'].append(
+                   'cd ' + p.get('pane_current_path'))
             pconf['shell_command'].append(p.get('pane_current_command'))
             wconf['panes'].append(pconf)
             # logger.error(p)
